@@ -52,14 +52,11 @@ class Grapher:
         remember that the axes are inverted.
 
         """
-        df = pd.DataFrame([node.to_string() for node in self.nodes])
+
         """
-        preprocessing the raw csv files to favorable df 
+        preprocessing the raw nodes list to favorable df 
         """
         df = pd.DataFrame([node.getInfo() for node in self.nodes])
-        """
-        preprocessing the raw csv files to favorable df 
-        """
 
         temp = df.copy()
         temp.fillna('', inplace=True)
